# arviz-base

[![Run tests](https://github.com/arviz-devs/arviz-base/actions/workflows/test.yml/badge.svg)](https://github.com/arviz-devs/arviz-base/actions/workflows/test.yml)
[![External integration tests](https://dev.azure.com/ArviZ/ArviZ/_apis/build/status%2Farviz-devs.arviz-base?branchName=main)](https://dev.azure.com/ArviZ/ArviZ/_build/latest?definitionId=3&branchName=main)
[![codecov](https://codecov.io/gh/arviz-devs/arviz-base/branch/main/graph/badge.svg?token=RDT6XAA8U2)](https://codecov.io/gh/arviz-devs/arviz-base)
[![Powered by NumFOCUS](https://img.shields.io/badge/powered%20by-NumFOCUS-orange.svg?style=flat&colorA=E1523D&colorB=007D8A)](https://numfocus.org)

Base ArviZ features and converters (once finished).

We are currently working on splitting ArviZ into independent modules.
See https://github.com/arviz-devs/arviz/issues/2088 for more details.

---

A pre-release is already available on PyPI, install it with:

```
pip install arviz-base
```

More about ArviZ base at https://arviz-base.readthedocs.io
